#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://www.cgsecurity.org/wiki/TestDisk
# last revised     : 16.1.2009

softname='testdisk'
softversion='6.11'
packageversion='62.1'

arch='i486'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.cgsecurity.org/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
testdisk: testdisk - data recovery sofware
testdisk:
testdisk: TestDisk is a powerful free data recovery software!
testdisk: It was primarily designed to help recover lost partitions 
testdisk: and/or make non-booting disks bootable again.
testdisk:
testdisk: PhotoRec is file data recovery software designed to recover 
testdisk: lost files. PhotoRec ignores the filesystem and goes after the
testdisk: underlying data.
testdisk: 
testdisk:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
	./configure \
      --prefix=$prefix \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest
    
# add 'default' files
    mv $dest/usr/share/doc/$softname-$softversion/html $dest/usr/doc/$softname-$softversion 
	rm -rf $dest/usr/share
	cp -a \
      INSTALL INFO THANKS NEWS ChangeLog AUTHORS COPYING README \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# Compress Man Pages
mv $dest/$prefix/share/man $dest/$prefix/
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#dep file
echo -e "e2fsprogs,libjpeg,ncurses,ntfsprogs,progsreiserfs" > $package.dep

#
# erase source
#
rm -rf $src
rm -rf $dest

#
# generate source file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/ap/testdisk/source/build-testdisk.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
